@@ -13,6 +13,10 @@ googleLineChart <- function(id, options=list()) {
   tags$div(id=id, class="google-linechart-output", `data-options`=RJSONIO::toJSON(options))
 }
 
+googleHistogram <- function(id, options=list()) {
+  tags$div(id=id, class="google-histogram-output", `data-options`=RJSONIO::toJSON(options))
+}
+
 row <- function(...) {
 	tags$div(class="row", ...)
 }
@@ -53,7 +57,7 @@ shinyUI(pageWithSidebar(
     			multiple=TRUE, selected=1),
     textOutput('uncertaintyNote'),
     hr(),
-    HTML("<p><small><b>Data Source:</b> United Nations, Department of Economic and Social Affairs, Population Division: <a href='http://esa.un.org/unpd/wpp'>World Population Prospects</a>. <a href='http://esa.un.org/unpd/ppp'>Probabilistic projections</a> based on <a href='http://www.pnas.org/content/early/2012/08/13/1211452109.abstract'>Raftery et al. (2012, PNAS)</a></small></p><p><small>CSSS, University of Washington; <a href='http://bayespop.csss.washington.edu'>project website</a></small></p>"),
+    HTML("<p><small><b>Data Source:</b> United Nations, Department of Economic and Social Affairs, Population Division: <a href='http://esa.un.org/unpd/wpp' target='_blank'>World Population Prospects</a>. <a href='http://esa.un.org/unpd/ppp' target='_blank'>Probabilistic projections</a> based on <a href='http://www.pnas.org/content/early/2012/08/13/1211452109.abstract' target='_blank'>Raftery et al. (2012, PNAS)</a></small></p><p><small>Hana &#352;ev&#269;&#237;kov&#225;, <a href='https://www.csss.washington.edu' target='_blank'>CSSS</a>, University of Washington; <a href='http://bayespop.csss.washington.edu' target='_blank'>project website</a></small></p>"),
 width=3
   ),
   mainPanel(
@@ -93,17 +97,33 @@ width=3
 					col(0.5, ''),
 					col(2, uiOutput('cselection')),
 				  	col(7, tabsetPanel(
-				  				tabPanel('Median',
-				  					googleLineChart('trends', options=list(height=400, width=650)),
-				  					checkboxInput('median.logscale', 'Log scale', FALSE)),
-				  				tabPanel('Probabilistic trends', plotOutput('probtrends', height="400px", width="650px")),
+				  				#tabPanel('Median',
+				  				#	googleLineChart('trends', options=list(height=400, width=650)),
+				  				#	checkboxInput('median.logscale', 'Log scale', FALSE)),
+				  				tabPanel('Trends', 
+				  					plotOutput('probtrends', height="400px", width="650px", 
+				  							click = "probtrends_values", hover = "probtrends_values", 
+				  							dblclick = "probtrends_zoom_reset", 
+				  							brush = brushOpts(id = "probtrends_zoom", resetOnNew = TRUE)),
+				  					flowLayout(
+										checkboxInput('trend.logscale', 'Log scale', FALSE),
+										textOutput("probtrends_selected")
+										)
+				  					),
 				  				tabPanel('Age Profile', 
 				  					googleLineChart('age.profileM', options=list(height=200, width=650)),
 				  					googleLineChart('age.profileF', options=list(height=200, width=650)),
 				  					checkboxInput('aprofile.logscale', 'Log scale', FALSE)),
 				  				tabPanel('Pyramids', 
-				  					plotOutput('pyramids'),
-				  					checkboxInput('proppyramids', 'Pyramid of proportions', FALSE))				  			
+				  					plotOutput('pyramids', click = "pyramid_values", hover = "pyramid_values", 
+				  						dblclick = "pyramid_zoom_reset",
+				  						brush = brushOpts(id = "pyramid_zoom", resetOnNew = TRUE)
+									),
+				  					flowLayout(
+				  						checkboxInput('proppyramids', 'Pyramid of proportions', FALSE),
+				  						textOutput("pyramid_selected")
+									)
+				  				)	  			
 				  			)
 				  		)
  					),
@@ -115,10 +135,14 @@ width=3
  				)
  		),
  	tabPanel('Histogram',
- 		textOutput('year3'),
- 		hr(),
-      	checkboxInput('fiXscaleHist', 'Fixed x-axis over time', TRUE),
-      	plotOutput('hist')
+ 		#textOutput('year3'),
+ 		#hr(),
+ 		flowLayout(
+      	checkboxInput('fiXscaleHist', 'Fixed x-axis over time', FALSE)
+      	),
+      	hr(),
+      	#plotOutput('hist')
+      	htmlOutput('ghist')
     ),
       tabPanel('Rosling Chart',
 		htmlOutput('graphgvis'),
@@ -128,7 +152,10 @@ width=3
 			col(3, textOutput('AddIndicatorText')),
 			col(1, actionButton("AddIndicator", "Add indicator"))
 			)
-      )#,
+      ),
+      tabPanel("Help",
+      	includeHTML("README.html")
+      )
   ) #end tabsetPanel
   ) #end mainPanel
 ))
\ No newline at end of file
